@@ -6,23 +6,23 @@ from numpy.typing import NDArray
 import richdem as rd
 
 # MODULES
-import matrix
-import hydrogram
-import gtif
-import geotransform
+from .matrix import Matrix
+from .hydrogram import gen_hydrogram
+from .gtif import openf, as_array, get_rowcol
+from .geotransform import GeoTransformFit
 from .debug import print_exception, progress_counter  # , crono, truncate, progress_bar
 # from .geotransform import GeoTransformFit
 
 
-class MFD (matrix.Matrix):
+class MFD(Matrix):
 
     def __init__(self, dtm_path: str, manning_path: str, nodata: float = -999, mute: bool = True):
-        self.dtm_ds = gtif.openf(dtm_path)
+        self.dtm_ds = openf(dtm_path)
         self.dtm_gt = self.dtm_ds.GetGeoTransform()
-        self.mannings_ds = gtif.openf(manning_path)
+        self.mannings_ds = openf(manning_path)
         self.mannings_gt = self.mannings_ds.GetGeoTransform()
 
-        matrix.Matrix.__init__(self, gtif.as_array(self.dtm_ds))
+        Matrix.__init__(self, as_array(self.dtm_ds))
 
         self.cellsize = self.dtm_gt[1]
         self.cellarea = math.pow(self.cellsize, 2.0)
@@ -31,8 +31,8 @@ class MFD (matrix.Matrix):
         self.dtm = rd.rdarray(self.dtm, no_data=nodata)
         rd.FillDepressions(self.dtm, in_place=True)
 
-        self.mannings = self.array(gtif.as_array(self.mannings_ds))
-        self.mannings = geotransform.GeoTransformFit(
+        self.mannings = self.array(as_array(self.mannings_ds))
+        self.mannings = GeoTransformFit(
             self.mannings,
             self.mannings_gt,
             self.dtm_gt
@@ -189,9 +189,9 @@ class MFD (matrix.Matrix):
                 return next_step
 
         try:
-            src = gtif.get_rowcol(*src, ds=self.dtm_ds)
+            src = get_rowcol(*src, ds=self.dtm_ds)
             start, visited, slope = self.start_point(src, drafts)
-            hyd = hydrogram.gen_hydrogram(hydrogram_curve)
+            hyd = gen_hydrogram(hydrogram_curve)
             break_flow = 0
             while break_flow == 0:
                 break_flow = next(hyd)
